LIBRARY ieee;
USE ieee.std_logic_1164.ALL;

ENTITY Test_Bench_main IS
END Test_Bench_main;
 
ARCHITECTURE behavior OF Test_Bench_main IS 
 
    -- Component Declaration for the Unit Under Test (UUT)
    COMPONENT main
		generic( 
			word_width	: integer := 12
			);
		Port( 	
			-- inputs
			RESET 		: in std_logic;										
			
			DCO			: in std_logic;		
			FCO			: in std_logic;
			
			DIN			: in std_logic;
			
			-- outputs
			DOUT 			: out std_logic_vector(word_width-1 downto 0)
			);
    END COMPONENT;
    

   --Inputs
   signal RESET 		: std_logic := '0';
   signal DCO		 	: std_logic := '0';
   signal FCO		 	: std_logic := '0';
   signal DIN			: std_logic := '0';

 	--Outputs
   signal DOUT : std_logic_vector(12-1 downto 0);
   
   constant DCO_period : time := 10 ns;			-- DDR - Mode
   constant FCO_period : time := 20 ns;

	constant t_frame 		: time := 1 ns;
BEGIN
 
	-- Instantiate the Unit Under Test (UUT)
   uut: main PORT MAP (
          RESET 	=> RESET,
          DCO 		=> DCO,
          FCO 		=> FCO,
          DIN 		=> DIN,
          DOUT 	=> DOUT
        );

   -- Clock process definitions
   DCO_process :process
   variable i : integer := 0;
	begin
		if i = 0 then
			wait for t_frame;
			i := 1;
		end if;
		DCO <= '0';
		wait for DCO_period/2;
		DCO <= '1';
		wait for DCO_period/2;
   end process;
	
   FCO_process :process
	begin
		FCO <= '0';
		wait for FCO_period/2;
		FCO <= '1';
		wait for FCO_period/2;
   end process;
 
   -- Stimulus process
   stim_proc: process
   begin		
	
      RESET <= '1';
		wait for 100 ns;
		
		RESET <= '0';
		wait for DCO_period/2;
		
		DIN 	<= '0';					-- "0100"
		wait for DCO_period/2;
		DIN 	<= '1';
		wait for DCO_period/2;
		DIN 	<= '0';
		wait for DCO_period/2;
		DIN 	<= '0';
		
		wait for DCO_period/2;		-- "1100"
		DIN 	<= '1';
		wait for DCO_period/2;
		DIN 	<= '1';
		wait for DCO_period/2;
		DIN 	<= '0';
		wait for DCO_period/2;
		DIN 	<= '0';
		
		wait for DCO_period/2;		-- "0111"
		DIN 	<= '0';
		wait for DCO_period/2;
		DIN 	<= '1';
		wait for DCO_period/2;
		DIN 	<= '1';
		wait for DCO_period/2;
		DIN 	<= '1';
		
		wait for DCO_period/2;		-- "0000"
		DIN 	<= '0';
		wait for DCO_period/2;
		DIN 	<= '0';
		wait for DCO_period/2;
		DIN 	<= '0';
		wait for DCO_period/2;
		DIN 	<= '0';
		
		wait for DCO_period/2;		-- "1111"
		DIN 	<= '1';
		wait for DCO_period/2;
		DIN 	<= '1';
		wait for DCO_period/2;
		DIN 	<= '1';
		wait for DCO_period/2;
		DIN 	<= '1';
		
      wait;
   end process;
END;