----------------------------------------------------------------------------------
-- library 
----------------------------------------------------------------------------------
library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_UNSIGNED.all;

library UNISIM;
use UNISIM.VCOMPONENTS.all;

----------------------------------------------------------------------------------
-- entity 
----------------------------------------------------------------------------------
entity main is
	generic( 
		word_width	: integer := 12
		);
   Port( 	
		-- inputs
		RESET 		: in std_logic;										
		
		DCO			: in std_logic;		
		FCO			: in std_logic;
		
		DIN			: in std_logic;
		
		-- outputs
		DOUT 			: out std_logic_vector(word_width-1 downto 0)
		);
end main;

----------------------------------------------------------------------------------
-- architecture 
----------------------------------------------------------------------------------
architecture Behavioral of main is
	
	-------------------------------------------------------------------------------
	-- signals 
	-------------------------------------------------------------------------------
	signal low 				: std_logic := '0';
	signal high 			: std_logic := '1';
		
	signal bitslip_net 	: std_logic := '0';
	signal q_net 			: std_logic_vector(3 downto 0) := "0000";			
	
	signal IntDatDone		: std_logic := '1';		
	
begin

	ISERDES_Master : ISERDESE1
	generic map (
		SERDES_MODE			=> "MASTER",			 
		INTERFACE_TYPE		=> "NETWORKING",		 
		IOBDELAY				=> "NONE",				 
		DATA_RATE 			=> "DDR", 				 
		DATA_WIDTH 			=> 4,						
		DYN_CLKDIV_INV_EN	=> FALSE, 				 
		DYN_CLK_INV_EN		=> FALSE, 				
		NUM_CE				=> 1, 					 
		OFB_USED				=> FALSE 				 
	)
	port map(
		D						=> DIN,				-- serial data stream
		DDLY					=> Low, 
		DYNCLKDIVSEL		=> Low, 	
		DYNCLKSEL			=> Low, 		
		OFB					=> Low, 		
		BITSLIP				=> bitslip_net,	-- not used
		CE1					=> IntDatDone,		-- "IntDatDone" enables the ISERDES.
		CE2					=> Low,			
		RST					=> RESET,	   
		CLK					=> FCO, 				-- for testing 3xDCO (3 x 4 bit blocks = 12 bit)
		CLKB					=> Low, 		
		CLKDIV				=> DCO, 				-- adc data clock (max. 390 MHz)
		OCLK					=> Low, 	
		SHIFTOUT1			=> open, 		
		SHIFTOUT2			=> open, 	
		O						=> open, 		
		Q1						=> q_net(0), 
		Q2						=> q_net(1), 
		Q3						=> q_net(2),
		Q4						=> q_net(3),
		Q5						=> open, 		
		Q6						=> open, 		
		SHIFTIN1				=> Low, 	
		SHIFTIN2				=> Low 		
		);
end Behavioral;